import processing.serial.Serial;   // kniznica pre seriovu komunikaciu s Arduinom
import g4p_controls.*;             // graficka kniznica pre posuvnik
import java.awt.Font;              // kniznica pre pracu s fontami

/* ***************************************************************** */
/* Tento riadok treba upravit podla toho, na ktorom porte je Arduino */
/* ***************************************************************** */
static final int PORT_INDEX = 1, BAUDS = 9600;

GCustomSlider VoltageSlider;       // posuvnik pre napatie
GLabel VoltageLabel;               // zobrazovanie hodnoty posuvnika

float adcValue0 = 0;               // value received from Serial 
float adcValue1 = 0;               // value received from Serial 
String Unit0="V";                  // jednotky pre prvy kanal
String Unit1="V";                  // jednotky pre druhy kanal
// String Unit="kΩ";
// String Unit="°C";               // can use Unicode chars directly

Serial myPort;
PFont Segment, Units; 

boolean writeFlag=false;     
PrintWriter logFile;

void setup()              // Setup the display window 
 {
  size(580, 380);         // Size of the window
  Segment = createFont("DSEG7Classic-BoldItalic.ttf", 112);  // Assign fonts and size 
  Units = createFont("Arial", 40);
  textFont(Segment);
  textAlign(RIGHT);        // Text align 
  fill(250, 250, 0);       // Font color is yellow = red + green

  logFile = createWriter("myData.txt");


  println(Serial.list());    // List all the available serial ports
  // Then open the port  you're using, my is the first, i.e. '0'
  myPort = new Serial(this, Serial.list()[PORT_INDEX], BAUDS);
  // don't generate a serialEvent() unless you get a newline character:
  myPort.bufferUntil('\n');
  
  
  VoltageLabel = new GLabel(this, 0, 0, 130, 80);
  VoltageLabel.setTextAlign(GAlign.CENTER, GAlign.MIDDLE);
  VoltageLabel.setText("Output");
  VoltageLabel.setOpaque(false);
  VoltageLabel.setFont(new Font("Arial", Font.PLAIN, 24));

  //=============================================================
  // Slider with another custom skin
  // constructor is `Parent applet', the x, y position and length
  VoltageSlider = new GCustomSlider(this, 20, 350, 260, 80, "purple18px");
  // show          opaque  ticks value limits
  VoltageSlider.setShowDecor(false, true, true, true);
  VoltageSlider.setShowValue(true); 
  VoltageSlider.setNbrTicks(6);
  VoltageSlider.setStickToTicks(false);
  VoltageSlider.setEasing(10);
  VoltageSlider.setLimits(2.5f, 0f, 5.0f);  // init value, min, max
  VoltageSlider.setNumberFormat(G4P.DECIMAL, 2);
  VoltageSlider.setTextOrientation(G4P.ORIENT_RIGHT);
  VoltageSlider.setRotation(-PI/2);

}





void draw()              // Let's start to display
{                      
  background(0, 0, 0);   // set the background color black

  textFont(Units);       // nastav farbu a cislo kanala
  fill(0, 250, 0); 
  text("A0:", 200, 150);
  fill(250, 0, 0); 
  text("A1:", 200, 350);

  textFont(Segment);      // zobraznie samotnej veliciny
  fill(20, 30, 20);       // grey
  text("8.88", 500, 150);
  fill(0, 250, 0);  
  text(nf(adcValue0,1,2).replace(',', '.'), 500, 150);
  fill(30, 20, 20);       // grey
  text("8.88", 500, 350);
  fill(250, 0, 0); 
  text(nf(adcValue1,1,2).replace(',', '.'), 500, 350);
                          // musime nahradit v stringu des. ciarku bodkou 
  
  textFont(Units);        // zobraz prislusne jednotky
  fill(0, 250, 0); 
  text(Unit0, 565, 65);
  fill(250, 0, 0); 
  text(Unit1, 565, 265);
  
  
  // write data to text file
  if (writeFlag)
   { 
     logFile.println(adcValue0 + ";" + adcValue1);
     writeFlag=false;
   }  
}

/* Toto je kod, ktory sa vykona ak pride nieco po seriovej linke */

void serialEvent(Serial port) {
 
  String data=port.readStringUntil('\n');  // precitaj vsetko po koniec riadku
 
  if(data!=null)  {
   String[] vals = split(trim(data),',');  // rozdel data podla ciarky
 
    if(vals.length==2){
       adcValue0 = map(int(vals[0]), 0, 1023, 0, 5);  // prevod 0-1023 na 0-5 Volt
       adcValue1 = map(int(vals[1]), 0, 1023, 0, 5);
    }
  }
}


/* Tento kod sa zavola vzdy, ked niekto pohybe posuvnikom */ 
public void handleSliderEvents(GValueControl slider, GEvent event) { 
  String dcValueS;
  float dcValueF;
  int dcValueN;
  
  if (slider == VoltageSlider)         // je to ten spravny posuvnik?
    if (event == GEvent.VALUE_STEADY)  // ak uz prestnes hybat posuvatkom
     {       
       VoltageLabel.setText(VoltageSlider.getValueS() + " V");
       dcValueS = VoltageSlider.getValueS();
       dcValueS = dcValueS.replace(',', '.');
       dcValueF = float(dcValueS);
       dcValueF = map(dcValueF, 0.0, 5.0, 0.0, 255.0);
       dcValueN = int(dcValueF);
       println(VoltageSlider.getValueS() + "    " + dcValueN + "    " + event);
       myPort.write(dcValueN);   // toto posle Arduinu po seriovej linke data
       // myPort.write('\n');
       writeFlag=true;
     }  
}

/* Tento kod sa vyvola vzdy, ked niekto stlaci nejaky klaves */
void keyPressed() 
{
  if ((key == ENTER)) 
  {
    logFile.flush(); 
    logFile.close();
    }
}
